pub enum DiffError {
CalcError(CalcError),
Boxed(Box<dyn Error + Send + Sync>),
DerivativeNotFound,
UnknownError,
}Variants
CalcError(CalcError)
A function has had an error covered by CalcError
Mostly used for invalid arguments count
Boxed(Box<dyn Error + Send + Sync>)
A user-defined error
Is used when implementing custom function with differentiation logic
DerivativeNotFound
A function was encountered and it wasn’t registered as differentiable
UnknownError
Unknown error encountered